@@ -82,8 +82,6 @@ class Update(object):
 
             'public_html',
 
-            'shoretel_phones',
-
             'space_buildings',
             'space_desks',
             'space_rooms',
@@ -502,12 +500,6 @@ class Update(object):
         p = auth.people()
         return p.getVendorData('linkedin')
 
-    # shoretel
-    def get_shoretel_phones(self, auth):
-        """Return a dict of Shoretel phones for BITSdb."""
-        s = auth.shoretel()
-        return s.getPhones()
-
     # space
     def get_space_buildings(self, auth):
         """Return a dict of Space buildings for BITSdb."""
